commit 6c400b26128216953db962cb7698691dd04ee3bf
Author: John Naylor <jcnaylor@gmail.com>
Date:   Thu Jan 31 14:47:02 2019 +0100

    put FSM tests in brin.sql

diff --git a/contrib/pageinspect/expected/brin.out b/contrib/pageinspect/expected/brin.out
index 71eb190380..ef1304bdef 100644
--- a/contrib/pageinspect/expected/brin.out
+++ b/contrib/pageinspect/expected/brin.out
@@ -1,6 +1,7 @@
 CREATE TABLE test1 (a int, b text);
 INSERT INTO test1 VALUES (1, 'one');
 CREATE INDEX test1_a_idx ON test1 USING brin (a);
+VACUUM test1;  -- set up FSM
 SELECT brin_page_type(get_raw_page('test1_a_idx', 0));
  brin_page_type 
 ----------------
@@ -48,4 +49,39 @@ SELECT * FROM brin_page_items(get_raw_page('test1_a_idx', 2), 'test1_a_idx')
           1 |      0 |      1 | f        | f        | f           | {1 .. 1}
 (1 row)
 
+-- FSM tests
+-- These are here rather than in page.sql since BRIN indexes don't have a
+-- minimum threshold size to have a FSM
+SELECT octet_length(get_raw_page('test1_a_idx', 'fsm', 0)) AS fsm_0;
+ fsm_0 
+-------
+  8192
+(1 row)
+
+SELECT octet_length(get_raw_page('test1_a_idx', 'fsm', 1)) AS fsm_1;
+ fsm_1 
+-------
+  8192
+(1 row)
+
+SELECT * FROM fsm_page_contents(get_raw_page('test1_a_idx', 'fsm', 0));
+ fsm_page_contents 
+-------------------
+ 0: 254           +
+ 1: 254           +
+ 3: 254           +
+ 7: 254           +
+ 15: 254          +
+ 31: 254          +
+ 63: 254          +
+ 127: 254         +
+ 255: 254         +
+ 511: 254         +
+ 1023: 254        +
+ 2047: 254        +
+ 4095: 254        +
+ fp_next_slot: 0  +
+ 
+(1 row)
+
 DROP TABLE test1;
diff --git a/contrib/pageinspect/expected/page.out b/contrib/pageinspect/expected/page.out
index 3fcd9fbe6d..afa5f9fce2 100644
--- a/contrib/pageinspect/expected/page.out
+++ b/contrib/pageinspect/expected/page.out
@@ -1,7 +1,9 @@
 CREATE EXTENSION pageinspect;
 CREATE TABLE test1 (a int, b int);
 INSERT INTO test1 VALUES (16777217, 131584);
-VACUUM test1;  -- set up FSM
+-- set up VM
+-- Note: This heap is too small to have a FSM, so FSM tests are in brin.sql
+VACUUM test1;
 -- The page contents can vary, so just test that it can be read
 -- successfully, but don't keep the output.
 SELECT octet_length(get_raw_page('test1', 'main', 0)) AS main_0;
@@ -12,18 +14,6 @@ SELECT octet_length(get_raw_page('test1', 'main', 0)) AS main_0;
 
 SELECT octet_length(get_raw_page('test1', 'main', 1)) AS main_1;
 ERROR:  block number 1 is out of range for relation "test1"
-SELECT octet_length(get_raw_page('test1', 'fsm', 0)) AS fsm_0;
- fsm_0 
--------
-  8192
-(1 row)
-
-SELECT octet_length(get_raw_page('test1', 'fsm', 1)) AS fsm_1;
- fsm_1 
--------
-  8192
-(1 row)
-
 SELECT octet_length(get_raw_page('test1', 'vm', 0)) AS vm_0;
  vm_0 
 ------
@@ -62,26 +52,6 @@ SELECT tuple_data_split('test1'::regclass, t_data, t_infomask, t_infomask2, t_bi
  {"\\x01000001","\\x00020200"}
 (1 row)
 
-SELECT * FROM fsm_page_contents(get_raw_page('test1', 'fsm', 0));
- fsm_page_contents 
--------------------
- 0: 254           +
- 1: 254           +
- 3: 254           +
- 7: 254           +
- 15: 254          +
- 31: 254          +
- 63: 254          +
- 127: 254         +
- 255: 254         +
- 511: 254         +
- 1023: 254        +
- 2047: 254        +
- 4095: 254        +
- fp_next_slot: 0  +
- 
-(1 row)
-
 DROP TABLE test1;
 -- check that using any of these functions with a partitioned table or index
 -- would fail
diff --git a/contrib/pageinspect/sql/brin.sql b/contrib/pageinspect/sql/brin.sql
index 735bc3b673..a3bd93582d 100644
--- a/contrib/pageinspect/sql/brin.sql
+++ b/contrib/pageinspect/sql/brin.sql
@@ -1,6 +1,7 @@
 CREATE TABLE test1 (a int, b text);
 INSERT INTO test1 VALUES (1, 'one');
 CREATE INDEX test1_a_idx ON test1 USING brin (a);
+VACUUM test1;  -- set up FSM
 
 SELECT brin_page_type(get_raw_page('test1_a_idx', 0));
 SELECT brin_page_type(get_raw_page('test1_a_idx', 1));
@@ -15,4 +16,11 @@ SELECT * FROM brin_revmap_data(get_raw_page('test1_a_idx', 1)) LIMIT 5;
 SELECT * FROM brin_page_items(get_raw_page('test1_a_idx', 2), 'test1_a_idx')
     ORDER BY blknum, attnum LIMIT 5;
 
+-- FSM tests
+-- These are here rather than in page.sql since BRIN indexes don't have a
+-- minimum threshold size to have a FSM
+SELECT octet_length(get_raw_page('test1_a_idx', 'fsm', 0)) AS fsm_0;
+SELECT octet_length(get_raw_page('test1_a_idx', 'fsm', 1)) AS fsm_1;
+SELECT * FROM fsm_page_contents(get_raw_page('test1_a_idx', 'fsm', 0));
+
 DROP TABLE test1;
diff --git a/contrib/pageinspect/sql/page.sql b/contrib/pageinspect/sql/page.sql
index 8ac9991837..4b8c1190ab 100644
--- a/contrib/pageinspect/sql/page.sql
+++ b/contrib/pageinspect/sql/page.sql
@@ -3,7 +3,9 @@ CREATE EXTENSION pageinspect;
 CREATE TABLE test1 (a int, b int);
 INSERT INTO test1 VALUES (16777217, 131584);
 
-VACUUM test1;  -- set up FSM
+-- set up VM
+-- Note: This heap is too small to have a FSM, so FSM tests are in brin.sql
+VACUUM test1;
 
 -- The page contents can vary, so just test that it can be read
 -- successfully, but don't keep the output.
@@ -11,9 +13,6 @@ VACUUM test1;  -- set up FSM
 SELECT octet_length(get_raw_page('test1', 'main', 0)) AS main_0;
 SELECT octet_length(get_raw_page('test1', 'main', 1)) AS main_1;
 
-SELECT octet_length(get_raw_page('test1', 'fsm', 0)) AS fsm_0;
-SELECT octet_length(get_raw_page('test1', 'fsm', 1)) AS fsm_1;
-
 SELECT octet_length(get_raw_page('test1', 'vm', 0)) AS vm_0;
 SELECT octet_length(get_raw_page('test1', 'vm', 1)) AS vm_1;
 
@@ -29,8 +28,6 @@ SELECT page_checksum(get_raw_page('test1', 0), 0) IS NOT NULL AS silly_checksum_
 SELECT tuple_data_split('test1'::regclass, t_data, t_infomask, t_infomask2, t_bits)
     FROM heap_page_items(get_raw_page('test1', 0));
 
-SELECT * FROM fsm_page_contents(get_raw_page('test1', 'fsm', 0));
-
 DROP TABLE test1;
 
 -- check that using any of these functions with a partitioned table or index
